#ifndef NT2_INCLUDE_FUNCTIONS_MINUSONE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINUSONE_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/minusone.hpp>

#endif
